Task: Wikipedia
================
Description: Dump of Wikipedia articles from 2/3/18

Tags: #Wikipedia, #All

Notes: Specify ':full' for the full articles to be returned, otherwise defaults to ':summary', which provides the first paragraphs. To put the article in the labels and the title in the text, specify ':key-value' at the end (for a title/content key-value association)

